declare module "lib/getControlFunction" {
    /**
     * For a given `controlNumber` and `controlValue`, get the human-readable
     * function name, as defined in the MIDI specification.
     */
    const getControlFunction: (controlNumber: number, controlValue: number) => "bankselect" | "modulation" | "breathcontroller" | "footcontroller" | "portamentotime" | "dataentry" | "volume" | "balance" | "pan" | "expressioncontroller" | "effect1" | "effect2" | "generalpurposecontroller1" | "generalpurposecontroller2" | "generalpurposecontroller3" | "generalpurposecontroller4" | "bankselectfine" | "modulationfine" | "breathcontrollerfine" | "footcontrollerfine" | "portamentotimefine" | "dataentryfine" | "volumefine" | "balancefine" | "panfine" | "expressioncontrollerfine" | "effect1fine" | "effect2fine" | "generalpurposecontroller1fine" | "generalpurposecontroller2fine" | "generalpurposecontroller3fine" | "generalpurposecontroller4fine" | "sustainoff" | "sustainon" | "portamentooff" | "portamentoon" | "sostenutooff" | "sostenutoon" | "softoff" | "softon" | "legatooff" | "legatoon" | "hold2off" | "hold2on" | "soundcontroller1" | "soundcontroller2" | "soundcontroller3" | "soundcontroller4" | "soundcontroller5" | "soundcontroller6" | "soundcontroller7" | "soundcontroller8" | "soundcontroller9" | "soundcontroller10" | "generalpurposecontroller5" | "generalpurposecontroller6" | "generalpurposecontroller7" | "generalpurposecontroller8" | "portamentocontrol" | "effectdepth1" | "effectdepth2" | "effectdepth3" | "effectdepth4" | "effectdepth5" | "dataincrement" | "datadecrement" | "nonregisteredparameternumberfine" | "nonregisteredparameternumber" | "registeredparameternumberfine" | "registeredparameternumber" | "allsoundoff" | "resetallcontrollers" | "localcontroloff" | "localcontrolon" | "allnotesoff" | "omnimodeoff" | "omnimodeon" | "monomodeon" | "polymodeon" | null;
    export default getControlFunction;
}
declare module "lib/constants" {
    export const BITS_PER_DATA = 7;
    export const DATA_RANGE: number;
    export const DATA_RANGE_WITH_LSB: number;
    export const PITCH_BEND_NEUTRAL: number;
}
declare module "lib/numberUtils" {
    /**
     * Combine "Most Significant Byte" and "Least Significant Byte" for
     * parameters that use 2 bytes instead of just 1 for increased resolution.
     */
    export const combineMsbAndLsb: (msb: number, lsb: number) => number;
}
declare module "parseMidi" {
    /**
     * Parse data from a midimessage event.
     */
    const parseMidi: ([status, data1, data2]: number[] | Uint8Array) => {
        messageType: "noteoff";
        key: number;
        velocity: number;
        messageCode: number;
        channel: number;
    } | {
        messageType: "noteon";
        key: number;
        velocity: number;
        messageCode: number;
        channel: number;
    } | {
        messageType: "keypressure";
        key: number;
        pressure: number;
        messageCode: number;
        channel: number;
    } | {
        messageType: "controlchange";
        controlNumber: number;
        controlFunction: "bankselect" | "modulation" | "breathcontroller" | "footcontroller" | "portamentotime" | "dataentry" | "volume" | "balance" | "pan" | "expressioncontroller" | "effect1" | "effect2" | "generalpurposecontroller1" | "generalpurposecontroller2" | "generalpurposecontroller3" | "generalpurposecontroller4" | "bankselectfine" | "modulationfine" | "breathcontrollerfine" | "footcontrollerfine" | "portamentotimefine" | "dataentryfine" | "volumefine" | "balancefine" | "panfine" | "expressioncontrollerfine" | "effect1fine" | "effect2fine" | "generalpurposecontroller1fine" | "generalpurposecontroller2fine" | "generalpurposecontroller3fine" | "generalpurposecontroller4fine" | "sustainoff" | "sustainon" | "portamentooff" | "portamentoon" | "sostenutooff" | "sostenutoon" | "softoff" | "softon" | "legatooff" | "legatoon" | "hold2off" | "hold2on" | "soundcontroller1" | "soundcontroller2" | "soundcontroller3" | "soundcontroller4" | "soundcontroller5" | "soundcontroller6" | "soundcontroller7" | "soundcontroller8" | "soundcontroller9" | "soundcontroller10" | "generalpurposecontroller5" | "generalpurposecontroller6" | "generalpurposecontroller7" | "generalpurposecontroller8" | "portamentocontrol" | "effectdepth1" | "effectdepth2" | "effectdepth3" | "effectdepth4" | "effectdepth5" | "dataincrement" | "datadecrement" | "nonregisteredparameternumberfine" | "nonregisteredparameternumber" | "registeredparameternumberfine" | "registeredparameternumber" | "allsoundoff" | "resetallcontrollers" | "localcontroloff" | "localcontrolon" | "allnotesoff" | "omnimodeoff" | "omnimodeon" | "monomodeon" | "polymodeon" | null;
        controlValue: number;
        messageCode: number;
        channel: number;
    } | {
        messageType: "channelmodechange";
        controlNumber: number;
        channelModeMessage: "bankselect" | "modulation" | "breathcontroller" | "footcontroller" | "portamentotime" | "dataentry" | "volume" | "balance" | "pan" | "expressioncontroller" | "effect1" | "effect2" | "generalpurposecontroller1" | "generalpurposecontroller2" | "generalpurposecontroller3" | "generalpurposecontroller4" | "bankselectfine" | "modulationfine" | "breathcontrollerfine" | "footcontrollerfine" | "portamentotimefine" | "dataentryfine" | "volumefine" | "balancefine" | "panfine" | "expressioncontrollerfine" | "effect1fine" | "effect2fine" | "generalpurposecontroller1fine" | "generalpurposecontroller2fine" | "generalpurposecontroller3fine" | "generalpurposecontroller4fine" | "sustainoff" | "sustainon" | "portamentooff" | "portamentoon" | "sostenutooff" | "sostenutoon" | "softoff" | "softon" | "legatooff" | "legatoon" | "hold2off" | "hold2on" | "soundcontroller1" | "soundcontroller2" | "soundcontroller3" | "soundcontroller4" | "soundcontroller5" | "soundcontroller6" | "soundcontroller7" | "soundcontroller8" | "soundcontroller9" | "soundcontroller10" | "generalpurposecontroller5" | "generalpurposecontroller6" | "generalpurposecontroller7" | "generalpurposecontroller8" | "portamentocontrol" | "effectdepth1" | "effectdepth2" | "effectdepth3" | "effectdepth4" | "effectdepth5" | "dataincrement" | "datadecrement" | "nonregisteredparameternumberfine" | "nonregisteredparameternumber" | "registeredparameternumberfine" | "registeredparameternumber" | "allsoundoff" | "resetallcontrollers" | "localcontroloff" | "localcontrolon" | "allnotesoff" | "omnimodeoff" | "omnimodeon" | "monomodeon" | "polymodeon" | null;
        controlValue: number;
        messageCode: number;
        channel: number;
    } | {
        messageType: "programchange";
        program: number;
        messageCode: number;
        channel: number;
    } | {
        messageType: "channelpressure";
        pressure: number;
        messageCode: number;
        channel: number;
    } | {
        messageType: "pitchbendchange";
        pitchBend: number;
        pitchBendMultiplier: number;
        messageCode: number;
        channel: number;
    } | {
        messageType: "unknown";
        data1: number;
        data2: number;
        messageCode: number;
        channel: number;
    };
    export default parseMidi;
}
